diff --git a/test/workflows/geant_ip/test_create_imported_geant_ip.py b/test/workflows/geant_ip/test_create_imported_geant_ip.py
index ada6b7ddcd0a3144b18155a8a07f6b0d6d977d11..4ce636ea7dc53ac072e809853c6ef8768d2b584f 100644
--- a/test/workflows/geant_ip/test_create_imported_geant_ip.py
+++ b/test/workflows/geant_ip/test_create_imported_geant_ip.py
@@ -60,7 +60,7 @@ def imported_geant_ip_creation_input_form_data(edge_port_subscription_factory, p
 
 
 def test_create_imported_geant_ip_success(faker, imported_geant_ip_creation_input_form_data):
-    result, _, _ = run_workflow("create_imported_geant_ip", [imported_geant_ip_creation_input_form_data])
+    result, _, _ = run_workflow("create_imported_nren_l3_core_service", [imported_geant_ip_creation_input_form_data])
     state = extract_state(result)
     subscription = ImportedNRENL3CoreService.from_subscription(state["subscription_id"])
     assert_complete(result)
diff --git a/gso/workflows/nren_l3_core_service/create_imported_nren_l3_core_service.py b/gso/workflows/nren_l3_core_service/create_imported_nren_l3_core_service.py
index 81dc3f0b5db25da3a4dfb890a366ef23533892c9..b39d094c0e32dc9da3aa45f4106c26aa8b6d2759 100644
--- a/gso/workflows/nren_l3_core_service/create_imported_nren_l3_core_service.py
+++ b/gso/workflows/nren_l3_core_service/create_imported_nren_l3_core_service.py
@@ -1,4 +1,4 @@
 """A creation workflow for adding an existing GEANT IP to the service database."""
 
 from uuid import uuid4
 
@@ -88,11 +88,11 @@ def initialize_subscription(subscription: ImportedNRENL3CoreServiceInactive, ser
             sbp_bgp_session_list=sbp_bgp_session_list,
             **service_binding_port,
         )
-        subscription.geant_ip.geant_ip_ap_list.append(
+        subscription.nren_l3_core_service.nren_ap_list.append(
             NRENAccessPortInactive.new(
                 subscription_id=uuid4(),
-                nren_ap_type=service_binding_port["ap_type"],
-                geant_ip_sbp=service_binding_port_subscription,
+                ap_type=service_binding_port["ap_type"],
+                sbp=service_binding_port_subscription,
             )
         )
 
@@ -1,4 +1,4 @@
-"""A creation workflow for adding an existing GEANT IP to the service database."""
+"""A creation workflow for adding an existing NREN L3 Core Service to the service database."""
 
 from uuid import uuid4